import rasax.community.api.blueprints.project as project
from rasax.community.constants import RASA_PRODUCTION_ENVIRONMENT
from rasax.community.services.stack_service import StackService


async def test_collect_stack_results(stack_service: StackService):
    stack_services = {
        RASA_PRODUCTION_ENVIRONMENT: stack_service,
        "development": stack_service,
    }

    async def status():
        return {"version": "1.0"}

    stack_service.status = status

    actual = await project.collect_stack_results(stack_services)

    assert actual == {
        RASA_PRODUCTION_ENVIRONMENT: {"version": "1.0", "status": 200},
        "development": {"version": "1.0", "status": 200},
    }


async def test_collect_stack_results_with_exceptions(stack_service: StackService):
    stack_services = {RASA_PRODUCTION_ENVIRONMENT: stack_service}
    exception = Exception()

    async def status():
        raise exception

    stack_service.status = status

    actual = await project.collect_stack_results(stack_services)

    assert actual == {
        RASA_PRODUCTION_ENVIRONMENT: {"status": 500, "message": exception}
    }
